@@ -5,7 +5,7 @@ autoreconf
 ./configure \
   $PKGCFG \
   $CROSSCFG \
-  --with-ptw32=$PREFIX/usr/i686-w64-mingw32.static \
+  --with-ptw32=$PREFIX/i686-w64-mingw32.static \
   --with-libiconv-prefix=$PREFIX/iconv \
   --enable-static \
   PTW32_LIBS="-lpthread -lpcreposix -lpcre -lregex" \
