@@ -33,6 +33,8 @@ public:
 	
 	void initialize();
 
+	bool check();
+
 	long get_vfoA();
 	void set_vfoA(long);
 	long get_vfoB();
@@ -130,8 +132,6 @@ public:
 	void get_cw_spot_tone_min_max_step(int &min, int &max, int &step) {
 		min = 400; max = 800; step = 100; }
 
-	void set_band_selection(int v);
-
 	void get_nr_min_max_step(int &min, int &max, int &step) {
 		min = 1; max = 11; step = 1; }
 
@@ -147,6 +147,11 @@ public:
 	int def_bandwidth(int);
 	const char ** bwtable(int);
 
+	void set_BANDWIDTHS(std::string s);
+	std::string get_BANDWIDTHS();
+
+	void get_band_selection(int v);
+
 };
 
 #endif
