@@ -37,6 +37,8 @@ public:
 
 	void initialize();
 
+	bool check();
+
 	long get_vfoA();
 	void set_vfoA(long);
 
@@ -67,6 +69,9 @@ public:
 	int  adjust_bandwidth(int val);
 	int  def_bandwidth(int val);
 
+	void set_BANDWIDTHS(std::string s);
+	std::string get_BANDWIDTHS();
+
 	int  get_smeter();
 	int  get_swr();
 	int  get_power_out();
@@ -74,7 +79,7 @@ public:
 	void set_volume_control(int val);
 	void set_power_control(double val);
 	void get_pc_min_max_step(double &min, double &max, double &step) {
-		min = 5; max = 200; step = 1; }
+		min = 10; max = 200; step = 1; }
 
 	int  get_volume_control();
 	void set_PTT_control(int val);
@@ -127,7 +132,7 @@ public:
 	bool set_cw_spot();
 //	void set_cw_spot_tone();
 
-	void set_band_selection(int v);
+	void get_band_selection(int v);
 };
 
 
