@@ -53,8 +53,9 @@ public:
 	
 	bool twovfos() {return true;}
 
-	bool canswap() {return true;}
-	void swapvfos();
+	bool canswap() {return false;}
+
+	bool check();
 
 	long get_vfoA();
 	void set_vfoA(long);
