@@ -35,6 +35,8 @@ public:
 	void post_initialize();
 	void shutdown();
 
+	bool check();
+
 	long get_vfoA();
 	void set_vfoA(long);
 
@@ -65,6 +67,9 @@ public:
 	int  adjust_bandwidth(int val);
 	int  def_bandwidth(int val);
 
+	void set_BANDWIDTHS(std::string s);
+	std::string get_BANDWIDTHS();
+
 	int  get_smeter();
 	int  get_swr();
 	int  get_alc();
@@ -124,7 +129,7 @@ public:
 	void set_cw_qsk();
 	bool set_cw_spot();
 	void set_cw_spot_tone();
-	void set_band_selection(int v);
+	void get_band_selection(int v);
 	void get_nr_min_max_step(int &min, int &max, int &step) {
 		min = 1; max = 15; step = 1; }	
 	void set_noise_reduction_val(int val);
