@@ -34,6 +34,8 @@ public:
 
 	void initialize();
 
+	bool check();
+
 	long get_vfoA();
 	void set_vfoA(long);
 
@@ -64,8 +66,12 @@ public:
 	int  adjust_bandwidth(int val);
 	int  def_bandwidth(int val);
 
+	void set_BANDWIDTHS(std::string s);
+	std::string get_BANDWIDTHS();
+
 	int  get_smeter();
 	int  get_swr();
+	int  get_alc();
 	int  get_power_out();
 	int  get_power_control();
 	void set_volume_control(int val);
@@ -124,7 +130,7 @@ public:
 	bool set_cw_spot();
 //	void set_cw_spot_tone();
 
-	void set_band_selection(int v);
+	void get_band_selection(int v);
 };
 
 
