@@ -33,6 +33,8 @@ public:
 	void selectA();
 	void selectB();
 
+	bool check();
+
 	long get_vfoA ();
 	void set_vfoA (long freq);
 
@@ -144,17 +146,25 @@ public:
 	int get_preamp();
 	int next_preamp();
 
+	void set_pbt_inner(int val);
+	void set_pbt_outer(int val);
+
+	int  get_pbt_inner();
+	int  get_pbt_outer();
+
 	bool canswap() { return true; }
-	bool ICswap() { return true; }
 
 //	bool hasA2b() { return true; }
 
-	const char **bwtable(int m) {return bandwidths_;}
+	const char **bwtable(int m);
 
 	void set_PTT_control(int val);
 	int  get_PTT();
 	void tune_rig();
 
+	void set_band_selection(int v);
+	void get_band_selection(int v);
+
 };
 
 #endif
