@@ -49,6 +49,7 @@
 #include <FL/Fl_Counter.H>
 #include <FL/Fl_Simple_Counter.H>
 #include <FL/Fl_Progress.H>
+#include <FL/Fl_Input_Choice.H>
 
 #include "flinput2.h"
 #include "Fl_SigBar.h"
@@ -56,6 +57,7 @@
 #include "combo.h"
 #include "ValueSlider.h"
 #include "hspinner.h"
+#include "pl_tones.h"
 
 extern Fl_Double_Window* XcvrDialog();
 extern Fl_Double_Window* MetersDialog();
@@ -65,6 +67,7 @@ extern Fl_Double_Window* Memory_Dialog();
 extern Fl_Double_Window* Wide_rig_window();
 extern Fl_Double_Window* Small_rig_window();
 extern Fl_Double_Window* touch_rig_window();
+extern Fl_Double_Window* tabs_window();
 
 extern void select_power_meter_scales();
 
@@ -101,6 +104,7 @@ extern Fl_ComboBox *opBW;
 extern Fl_Button *btnDSP;
 extern Fl_ComboBox *opDSP_lo;
 extern Fl_ComboBox *opDSP_hi;
+extern Fl_Button *btnFILT;
 extern Fl_ComboBox *opMODE;
 extern Fl_Group *grp_row1b;
 extern Fl_Group *grp_row1b1;
@@ -133,6 +137,11 @@ extern Fl_Wheel_Value_Slider *sldrRFGAIN;
 extern Fl_Box *bx_sep2c;
 extern Fl_Group *grp_row2d;
 
+extern Fl_Light_Button *btnLOCK;
+extern Fl_Button *btnCLRPBT;
+extern Fl_Wheel_Value_Slider *sldrINNER;
+extern Fl_Wheel_Value_Slider *sldrOUTER;
+
 extern Fl_Wheel_Value_Slider *sldrPOWER;
 
 extern Fl_Light_Button *btnPOWER;
@@ -150,19 +159,42 @@ extern Fl_Wheel_Value_Slider *sldrVOLUME;
 extern Fl_Group *grpTABS;
 
 extern Fl_Tabs *tabsGeneric;
-extern Fl_Group *genericBands;
-extern Fl_Button *btnBandSelect_1;
-extern Fl_Button *btnBandSelect_2;
-extern Fl_Button *btnBandSelect_3;
-extern Fl_Button *btnBandSelect_4;
-extern Fl_Button *btnBandSelect_5;
-extern Fl_Button *btnBandSelect_6;
-extern Fl_Button *btnBandSelect_7;
-extern Fl_Button *btnBandSelect_8;
-extern Fl_Button *btnBandSelect_9;
-extern Fl_Button *btnBandSelect_10;
-extern Fl_Button *btnBandSelect_11;
-extern Fl_ComboBox *opSelect60;
+extern Fl_Group *hidden_tabs;
+extern Fl_Group *tab_yaesu_bands;
+extern Fl_Button *btn_yaesu_select_1;
+extern Fl_Button *btn_yaesu_select_2;
+extern Fl_Button *btn_yaesu_select_3;
+extern Fl_Button *btn_yaesu_select_4;
+extern Fl_Button *btn_yaesu_select_5;
+extern Fl_Button *btn_yaesu_select_6;
+extern Fl_Button *btn_yaesu_select_7;
+extern Fl_Button *btn_yaesu_select_8;
+extern Fl_Button *btn_yaesu_select_9;
+extern Fl_Button *btn_yaesu_select_10;
+extern Fl_Button *btn_yaesu_select_11;
+extern Fl_ComboBox *op_yaesu_select60;
+
+extern Fl_Group *tab_icom_bands;
+extern Fl_Button *btn_icom_select_1;
+extern Fl_Button *btn_icom_select_2;
+extern Fl_Button *btn_icom_select_3;
+extern Fl_Button *btn_icom_select_4;
+extern Fl_Button *btn_icom_select_5;
+extern Fl_Button *btn_icom_select_6;
+extern Fl_Button *btn_icom_select_7;
+extern Fl_Button *btn_icom_select_8;
+extern Fl_Button *btn_icom_select_9;
+extern Fl_Button *btn_icom_select_10;
+extern Fl_Button *btn_icom_select_11;
+extern Fl_Button *btn_icom_select_12;
+extern Fl_Button *btn_icom_select_13;
+
+extern Fl_PL_tone *choice_tTONE;
+extern Fl_PL_tone *choice_rTONE;
+
+extern int PL_tones[50];
+extern const char *szTONES;
+
 extern Fl_Group *genericCW;
 extern Fl_Light_Button *btnSpot;
 
@@ -171,6 +203,12 @@ extern Fl_Button *btnBreakIn;
 extern Hspinner *spnr_cw_delay;
 extern Hspinner *cnt_cw_qsk;
 
+extern Fl_Group *tab7610;
+extern Fl_ComboBox *ic7610att;
+extern Fl_Light_Button *ic7610dual_watch;
+extern Fl_Light_Button *ic7610digi_sel_on_off;
+extern Fl_Wheel_Value_Slider *ic7610_digi_sel_val;
+
 extern Fl_Group  *genericUser;
 extern Fl_Button *btnUser1;
 extern Fl_Button *btnUser2;
@@ -382,6 +420,7 @@ extern Fl_Group *tabAux;
 extern Fl_ComboBox *selectAuxPort;
 extern Fl_Check_Button *btnAux_SCU_17;
 extern Fl_Group *tabPolling;
+extern Fl_Group *tabTRACE;
 extern Fl_Group *tabRestore;
 extern Fl_Group *tabTCPIP;
 extern Fl_Group *tabXMLRPC;
@@ -405,6 +444,7 @@ extern Fl_Value_Input *poll_squelch;
 extern Fl_Value_Input *poll_split;
 extern Fl_Value_Input *poll_noise;
 extern Fl_Value_Input *poll_nr;
+extern Fl_Value_Input *poll_compression;
 extern Fl_Button *btnClearAddControls;
 extern Fl_Value_Input *poll_all;
 extern Fl_Button *btnSetAllAdd;
