@@ -99,6 +99,10 @@ struct status {
 	int		iBW_B;
 	int		imode_B;
 	int		freq_B;
+
+	std::string filters;
+	std::string bandwidths;
+
 	bool	use_rig_data;
 
 	bool	spkr_on;
@@ -109,6 +113,9 @@ struct status {
 	int		notch_val;
 	bool	shift;
 	int		shift_val;
+	bool	pbt_lock;
+	int		pbt_inner;
+	int		pbt_outer;
 	int		rfgain;
 	int		squelch;
 
@@ -146,6 +153,7 @@ struct status {
 	int		auto_notch;
 
 	int		split;
+	int		no_txqsy;
 
 	int		rx_avg;
 	int		rx_peak;
@@ -153,8 +161,13 @@ struct status {
 	int		pwr_peak;
 	int		pwr_scale;
 
-// ft950 reverse RG0; readings
+// ic7610 special controls
+	bool	digi_sel_on_off;
+	int		digi_sel_val;
+	int		index_ic7610att;
+	bool	dual_watch;
 
+// ft950 reverse RG0; readings
 	bool	ft950_rg_reverse;
 
 	bool	restore_frequency;
@@ -325,7 +338,14 @@ struct status {
 
 	bool	external_tuner;
 
-//	bool	fldigi_is_server;
+	bool	trace;
+	bool	rigtrace;
+	bool	settrace;
+	bool	gettrace;
+	bool	debugtrace;
+	bool	xmltrace;
+	bool	rpctrace;
+	int		rpc_level;
 
 	void saveLastState();
 	void loadLastState();
