@@ -19,9 +19,13 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
+#include <iostream>
+#include <sstream>
+
 #include "FT950.h"
 #include "debug.h"
 #include "support.h"
+#include "trace.h"
 
 #define FL950_WAIT_TIME 200
 
@@ -31,6 +35,12 @@ enum mFT950 {
 
 static const char FT950name_[] = "FT-950";
 
+#undef  NUM_MODES
+#define NUM_MODES  13
+
+static int mode_bwA[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
+static int mode_bwB[NUM_MODES] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
+
 static const char *FT950modes_[] = {
 "LSB", "USB", "CW", "FM", "AM", "RTTY-L",
 "CW-R", "PKT-L", "RTTY-U", "PKT-FM",
@@ -102,7 +112,8 @@ static GUI rig_widgets[]= {
 };
 
 RIG_FT950::RIG_FT950() {
-// base class values	
+// base class values
+//	IDstr = "ID";
 	name_ = FT950name_;
 	modes_ = FT950modes_;
 	bandwidths_ = FT950_widths_SSB;
@@ -223,25 +234,35 @@ void RIG_FT950::initialize()
 	if (p == string::npos) {
 		Channels_60m = US_60m_chan;
 		label_60m    = US_60m_label;
-		opSelect60->clear();
+		op_yaesu_select60->clear();
 		char **p = (char **)US_60m_label;
-		while (*p) opSelect60->add(*p++);
+		while (*p) op_yaesu_select60->add(*p++);
 	}
 	else {
 		Channels_60m = UK_60m_chan;
 		label_60m    = UK_60m_label;
-		opSelect60->clear();
+		op_yaesu_select60->clear();
 		char **p = (char **)UK_60m_label;
-		while (*p) opSelect60->add(*p++);
+		while (*p) op_yaesu_select60->add(*p++);
 	}
-	opSelect60->index(m_60m_indx);
+	op_yaesu_select60->index(m_60m_indx);
+	op_yaesu_select60->activate();
 
 }
 
 void RIG_FT950::post_initialize()
 {
-	enable_bandselect_btn(12, false);
-	enable_bandselect_btn(13, true);
+	enable_yaesu_bandselect(12, false);
+	enable_yaesu_bandselect(13, true);
+}
+
+bool RIG_FT950::check ()
+{
+	cmd = rsp = "FA";
+	cmd += ';';
+	int ret = wait_char(';',11, FL950_WAIT_TIME, "check", ASC);
+	if (ret >= 11) return true;
+	return false;
 }
 
 long RIG_FT950::get_vfoA ()
@@ -250,6 +271,8 @@ long RIG_FT950::get_vfoA ()
 	cmd += ';';
 	wait_char(';',11, FL950_WAIT_TIME, "get vfo A", ASC);
 
+	rig_trace(4, "get_vfoA()", cmd.c_str(), " => ", replystr.c_str());
+
 	size_t p = replystr.rfind(rsp);
 	if (p == string::npos) return freqA;
 	int f = 0;
@@ -269,6 +292,9 @@ void RIG_FT950::set_vfoA (long freq)
 	}
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET vfo A", cmd, replystr);
+
+	rig_trace(4, "set_vfoA()", cmd.c_str(), " => ", replystr.c_str());
+
 }
 
 long RIG_FT950::get_vfoB ()
@@ -277,6 +303,8 @@ long RIG_FT950::get_vfoB ()
 	cmd += ';';
 	wait_char(';',11, FL950_WAIT_TIME, "get vfo B", ASC);
 
+	rig_trace(4, "get_vfoB()", cmd.c_str(), " => ", replystr.c_str());
+
 	size_t p = replystr.rfind(rsp);
 	if (p == string::npos) return freqB;
 	int f = 0;
@@ -286,7 +314,6 @@ long RIG_FT950::get_vfoB ()
 	return freqB;
 }
 
-
 void RIG_FT950::set_vfoB (long freq)
 {
 	freqB = freq;
@@ -297,6 +324,8 @@ void RIG_FT950::set_vfoB (long freq)
 	}
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET vfo B", cmd, replystr);
+
+	rig_trace(4, "set_vfoB()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 void RIG_FT950::setVfoAdj(double v)
@@ -310,6 +339,7 @@ void RIG_FT950::setVfoAdj(double v)
 	cmd.append(cmdstr);
 	cmd.append(";");
 	sendCommand(cmd);
+	rig_trace(4, "set_VfoAdj()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 double RIG_FT950::getVfoAdj() 
@@ -318,6 +348,8 @@ double RIG_FT950::getVfoAdj()
 	sendCommand(cmd.append(";"));
 	wait_char(';',9, FL950_WAIT_TIME, "get Vfo Adjust", ASC);
 
+	rig_trace(4, "get_VfoAdj()", cmd.c_str(), " => ", replystr.c_str());
+
 	size_t p = replystr.rfind(rsp);
 	if (p == string::npos) return 0;
 	return (double)(atoi(&replystr[p+5]));
@@ -340,6 +372,8 @@ void RIG_FT950::selectA()
 	cmd = "FR0;FT2;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select A", cmd, replystr);
+
+	rig_trace(4, "selectA()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 void RIG_FT950::selectB()
@@ -347,6 +381,8 @@ void RIG_FT950::selectB()
 	cmd = "FR4;FT3;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "select B", cmd, replystr);
+
+	rig_trace(4, "selectB()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 void RIG_FT950::A2B()
@@ -354,6 +390,8 @@ void RIG_FT950::A2B()
 	cmd = "AB;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "vfo A --> B", cmd, replystr);
+
+	rig_trace(4, "A2B()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 bool RIG_FT950::can_split()
@@ -369,20 +407,24 @@ void RIG_FT950::set_split(bool val)
 			cmd = "FR4;FT2;";
 			sendCommand(cmd);
 			showresp(WARN, ASC, "Rx on B, Tx on A", cmd, replystr);
+			rig_trace(4, "RxB, TxA()", cmd.c_str(), " => ", replystr.c_str());
 		} else {
 			cmd = "FR4;FT3;";
 			sendCommand(cmd);
 			showresp(WARN, ASC, "Rx on B, Tx on B", cmd, replystr);
+			rig_trace(4, "RxB, TxB()", cmd.c_str(), " => ", replystr.c_str());
 		}
 	} else {
 		if (val) {
 			cmd = "FR0;FT3;";
 			sendCommand(cmd);
 			showresp(WARN, ASC, "Rx on A, Tx on B", cmd, replystr);
+			rig_trace(4, "RxA, TxB()", cmd.c_str(), " => ", replystr.c_str());
 		} else {
 			cmd = "FR0;FT2;";
 			sendCommand(cmd);
 			showresp(WARN, ASC, "Rx on A, Tx on A", cmd, replystr);
+			rig_trace(4, "RxA, TxA()", cmd.c_str(), " => ", replystr.c_str());
 		}
 	}
 	Fl::awake(highlight_vfo, (void *)0);
@@ -397,6 +439,9 @@ int RIG_FT950::get_split()
 	cmd = rsp = "FT";
 	cmd.append(";");
 	wait_char(';',4, FL950_WAIT_TIME, "get split tx vfo", ASC);
+
+	rig_trace(4, "get_split()", cmd.c_str(), " => ", replystr.c_str());
+
 	p = replystr.rfind(rsp);
 	if (p == string::npos) return false;
 	tx = replystr[p+2] - '0';
@@ -406,6 +451,8 @@ int RIG_FT950::get_split()
 	cmd.append(";");
 	wait_char(';',4, FL950_WAIT_TIME, "get split rx vfo", ASC);
 
+	rig_trace(4, "get_split()", cmd.c_str(), " => ", replystr.c_str());
+
 	p = replystr.rfind(rsp);
 	if (p == string::npos) return false;
 	rx = replystr[p+2] - '0';
@@ -498,6 +545,7 @@ void RIG_FT950::set_power_control(double val)
 	}
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET power", cmd, replystr);
+	rig_trace(4, "set_power_control()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 // Volume control return 0 ... 100
@@ -525,6 +573,8 @@ void RIG_FT950::set_volume_control(int val)
 	}
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET vol", cmd, replystr);
+
+	rig_trace(4, "set_volume_control()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 // Tranceiver PTT on/off
@@ -533,6 +583,9 @@ void RIG_FT950::set_PTT_control(int val)
 	cmd = val ? "TX1;" : "TX0;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET PTT", cmd, replystr);
+
+	rig_trace(4, "set_PTT_control()", cmd.c_str(), " => ", replystr.c_str());
+
 	ptt_ = val;
 }
 
@@ -639,6 +692,9 @@ void RIG_FT950::set_attenuator(int val)
 	cmd[3] += atten_level;
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET att", cmd, replystr);
+
+	rig_trace(4, "set_attenuator()", cmd.c_str(), " => ", replystr.c_str());
+
 }
 
 int RIG_FT950::get_attenuator()
@@ -688,6 +744,9 @@ void RIG_FT950::set_preamp(int val)
 	cmd[3] = '0' + preamp_level;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET preamp", cmd, replystr);
+
+	rig_trace(4, "set_preamp()", cmd.c_str(), " => ", replystr.c_str());
+
 }
 
 int RIG_FT950::get_preamp()
@@ -746,9 +805,17 @@ int RIG_FT950::adjust_bandwidth(int val)
 	return FT950_def_bw[val];
 }
 
-int RIG_FT950::def_bandwidth(int val)
+int RIG_FT950::def_bandwidth(int m)
 {
-	return FT950_def_bw[val];
+	int bw = adjust_bandwidth(m);
+	if (useB) {
+		if (mode_bwB[m] == -1)
+			mode_bwB[m] = bw;
+		return mode_bwB[m];
+	}
+	if (mode_bwA[m] == -1)
+		mode_bwA[m] = bw;
+	return mode_bwA[m];
 }
 
 const char ** RIG_FT950::bwtable(int n)
@@ -778,6 +845,9 @@ void RIG_FT950::set_modeA(int val)
 	cmd += ';';
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET mode A", cmd, replystr);
+
+	rig_trace(4, "set_modeA()", cmd.c_str(), " => ", replystr.c_str());
+
 	adjust_bandwidth(modeA);
 	if (val == mCW || val == mCW_R) return;
 	if (progStatus.spot_onoff) {
@@ -786,6 +856,9 @@ void RIG_FT950::set_modeA(int val)
 		cmd = "CS0;";
 		sendCommand(cmd);
 		showresp(WARN, ASC, "SET spot off", cmd, replystr);
+
+		rig_trace(4, "set_spot_off()", cmd.c_str(), " => ", replystr.c_str());
+
 		btnSpot->value(0);
 	}
 }
@@ -796,6 +869,8 @@ int RIG_FT950::get_modeA()
 	cmd += ';';
 	wait_char(';',5, FL950_WAIT_TIME, "get mode A", ASC);
 
+	rig_trace(4, "get_modeA()", cmd.c_str(), " => ", replystr.c_str());
+
 	size_t p = replystr.rfind(rsp);
 	if (p != string::npos) {
 		if (p + 3 < replystr.length()) {
@@ -817,6 +892,9 @@ void RIG_FT950::set_modeB(int val)
 	cmd += ';';
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET mode B", cmd, replystr);
+
+	rig_trace(4, "set_modeB()", cmd.c_str(), " => ", replystr.c_str());
+
 	adjust_bandwidth(modeB);
 	if (val == mCW || val == mCW_R) return;
 	if (progStatus.spot_onoff) {
@@ -825,6 +903,9 @@ void RIG_FT950::set_modeB(int val)
 		cmd = "CS0;";
 		sendCommand(cmd);
 		showresp(WARN, ASC, "SET spot off", cmd, replystr);
+
+		rig_trace(4, "set_spot off()", cmd.c_str(), " => ", replystr.c_str());
+
 		btnSpot->value(0);
 	}
 }
@@ -835,6 +916,8 @@ int RIG_FT950::get_modeB()
 	cmd += ';';
 	wait_char(';',5, FL950_WAIT_TIME, "get mode B", ASC);
 
+	rig_trace(4, "get_modeB()", cmd.c_str(), " => ", replystr.c_str());
+
 	size_t p = replystr.rfind(rsp);
 	if (p != string::npos) {
 		if (p + 3 < replystr.length()) {
@@ -859,6 +942,9 @@ void RIG_FT950::set_bwA(int val)
 		else cmd = "NA00;";
 		sendCommand(cmd);
 		showresp(WARN, ASC, "SET bw A", cmd, replystr);
+
+		rig_trace(4, "set_bwA()", cmd.c_str(), " => ", replystr.c_str());
+
 		return;
 	}
 	if ((((modeA == mLSB || modeA == mUSB) && val < 8)) ||
@@ -873,6 +959,10 @@ void RIG_FT950::set_bwA(int val)
 	cmd += ';';
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET bw A", cmd, replystr);
+
+	mode_bwA[modeA] = bwA;
+
+	rig_trace(4, "set_bwA()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 int RIG_FT950::get_bwA()
@@ -880,12 +970,16 @@ int RIG_FT950::get_bwA()
 	size_t p;
 	if (modeA == mFM || modeA == mAM || modeA == mFM_N || modeA == mAM_N) {
 		bwA = 0;
+		mode_bwA[modeA] = bwA;
 		return bwA;	
 	}
 	if (modeA == mPKT_FM) {
 		cmd = rsp = "NA0";
 		cmd += ';';
 		wait_char(';',5, FL950_WAIT_TIME, "get bw A narrow", ASC);
+
+		rig_trace(4, "get_bwA()", cmd.c_str(), " => ", replystr.c_str());
+
 		p = replystr.rfind(rsp);
 		if (p == string::npos) { bwA = 0; return bwA; }
 		if (p + 4 >= replystr.length()) { bwA = 0; return bwA; }
@@ -897,6 +991,8 @@ int RIG_FT950::get_bwA()
 	cmd += ';';
 	wait_char(';',6, FL950_WAIT_TIME, "get bw A", ASC);
 
+	rig_trace(4, "get_bwA()", cmd.c_str(), " => ", replystr.c_str());
+
 	p = replystr.rfind(rsp);
 	if (p == string::npos) return bwA;
 	if (p + 5 >= replystr.length()) return bwA;
@@ -912,6 +1008,7 @@ int RIG_FT950::get_bwA()
 	}
 	if (*idx == WVALS_LIMIT) i--;
 	bwA = i;
+	mode_bwA[modeA] = bwA;
 	return bwA;
 }
 
@@ -926,6 +1023,9 @@ void RIG_FT950::set_bwB(int val)
 		else cmd = "NA00;";
 		sendCommand(cmd);
 		showresp(WARN, ASC, "SET bw B", cmd, replystr);
+
+		rig_trace(4, "set_bwB()", cmd.c_str(), " => ", replystr.c_str());
+
 		return;
 	}
 	if ((((modeB == mLSB || modeB == mUSB) && val < 8)) ||
@@ -940,6 +1040,10 @@ void RIG_FT950::set_bwB(int val)
 	cmd += ';';
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET bw B", cmd, replystr);
+
+	mode_bwB[modeB] = bwB;
+
+	rig_trace(4, "set_bwB()", cmd.c_str(), " => ", replystr.c_str());
 }
 
 int RIG_FT950::get_bwB()
@@ -947,12 +1051,16 @@ int RIG_FT950::get_bwB()
 	size_t p;
 	if (modeB == mFM || modeB == mAM || modeB == mFM_N || modeB == mAM_N) {
 		bwB = 0;
+		mode_bwB[modeB] = bwB;
 		return bwB;
 	}
 	if (modeB == mPKT_FM) {
 		cmd = rsp = "NA0";
 		cmd += ';';
 		wait_char(';',5, FL950_WAIT_TIME, "get bw B narrow", ASC);
+
+		rig_trace(4, "get_bwB()", cmd.c_str(), " => ", replystr.c_str());
+
 		p = replystr.rfind(rsp);
 		if (p == string::npos) { bwB = 0; return bwB; }
 		if (p + 4 >= replystr.length()) { bwB = 0; return bwB; }
@@ -964,6 +1072,8 @@ int RIG_FT950::get_bwB()
 	cmd += ';';
 	wait_char(';',6, FL950_WAIT_TIME, "get bw B", ASC);
 
+	rig_trace(4, "get_bwB()", cmd.c_str(), " => ", replystr.c_str());
+
 	p = replystr.rfind(rsp);
 	if (p == string::npos) return bwB;
 	if (p + 5 >= replystr.length()) return bwB;
@@ -979,9 +1089,30 @@ int RIG_FT950::get_bwB()
 	}
 	if (*idx == WVALS_LIMIT) i--;
 	bwB = i;
+	mode_bwB[modeB] = bwB;
 	return bwB;
 }
 
+std::string RIG_FT950::get_BANDWIDTHS()
+{
+	stringstream s;
+	for (int i = 0; i < NUM_MODES; i++)
+		s << mode_bwA[i] << " ";
+	for (int i = 0; i < NUM_MODES; i++)
+		s << mode_bwB[i] << " ";
+	return s.str();
+}
+
+void RIG_FT950::set_BANDWIDTHS(std::string s)
+{
+	stringstream strm;
+	strm << s;
+	for (int i = 0; i < NUM_MODES; i++)
+		strm >> mode_bwA[i];
+	for (int i = 0; i < NUM_MODES; i++)
+		strm >> mode_bwB[i];
+}
+
 int RIG_FT950::get_modetype(int n)
 {
 	return FT950_mode_type[n];
@@ -998,6 +1129,9 @@ void RIG_FT950::set_if_shift(int val)
 	}
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET if shift", cmd, replystr);
+
+	rig_trace(4, "set_if_shift()", cmd.c_str(), " => ", replystr.c_str());
+
 }
 
 bool RIG_FT950::get_if_shift(int &val)
@@ -1029,6 +1163,9 @@ void RIG_FT950::set_notch(bool on, int val)
 		cmd = "BP00001;";
 		sendCommand(cmd);
 		showresp(WARN, ASC, "SET notch on", cmd, replystr);
+
+		rig_trace(4, "set_notch_on()", cmd.c_str(), " => ", replystr.c_str());
+
 		cmd = "BP01000;";
 		if (val % 10 >= 5) val += 10;
 		val /= 10;
@@ -1038,6 +1175,9 @@ void RIG_FT950::set_notch(bool on, int val)
 		}
 		sendCommand(cmd);
 		showresp(WARN, ASC, "SET notch val", cmd, replystr);
+
+		rig_trace(4, "set_notch_val()", cmd.c_str(), " => ", replystr.c_str());
+
 		return;
 	}
 
@@ -1045,6 +1185,9 @@ void RIG_FT950::set_notch(bool on, int val)
 	cmd = "BP00000;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET notch off", cmd, replystr);
+
+	rig_trace(4, "set_notch_off()", cmd.c_str(), " => ", replystr.c_str());
+
 }
 
 bool  RIG_FT950::get_notch(int &val)
@@ -1114,6 +1257,9 @@ void RIG_FT950::set_noise(bool b)
 	cmd[3] = '0' + FT950_blanker_level;
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET NB", cmd, replystr);
+
+	rig_trace(4, "set_NB()", cmd.c_str(), " => ", replystr.c_str());
+
 }
 
 int RIG_FT950::get_noise()
@@ -1148,6 +1294,9 @@ void RIG_FT950::set_mic_gain(int val)
 	}
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET mic", cmd, replystr);
+
+	rig_trace(4, "set_mic_gain()", cmd.c_str(), " => ", replystr.c_str());
+
 }
 
 int RIG_FT950::get_mic_gain()
@@ -1185,6 +1334,9 @@ void RIG_FT950::set_rf_gain(int val)
 	}
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET rfgain", cmd, replystr);
+
+	rig_trace(4, "set_rf_gain()", cmd.c_str(), " => ", replystr.c_str());
+
 }
 
 int  RIG_FT950::get_rf_gain()
@@ -1315,11 +1467,11 @@ void RIG_FT950::set_cw_vol()
 }
 */
 
-void RIG_FT950::set_band_selection(int v)
+void RIG_FT950::get_band_selection(int v)
 {
 	int chan_mem_on = false;
 	cmd = "IF;";
-	wait_char(';',27, FL950_WAIT_TIME, "get vfo mode in set_band_selection", ASC);
+	wait_char(';',27, FL950_WAIT_TIME, "get vfo mode in get_band_selection", ASC);
 	size_t p = replystr.rfind("IF");
 	if (p == string::npos) return;
 	if ((p + 26) >= replystr.length()) return;
@@ -1328,7 +1480,7 @@ void RIG_FT950::set_band_selection(int v)
 	}
 
 	if (v == 13) {
-		m_60m_indx = opSelect60->index();
+		m_60m_indx = op_yaesu_select60->index();
 		if (m_60m_indx)
 			cmd.assign("MC").append(Channels_60m[m_60m_indx]).append(";");
 		else if (chan_mem_on)
@@ -1336,11 +1488,12 @@ void RIG_FT950::set_band_selection(int v)
 	} else {		// v == 1..11 band selection OR return to vfo mode == 0
 		if (chan_mem_on) {
 			cmd = "VM;";
-			opSelect60->index(m_60m_indx = 0);
+			op_yaesu_select60->index(m_60m_indx = 0);
 		} else {
 			if (v < 3)
 				v = v - 1;
 			cmd.assign("BS").append(to_decimal(v, 2)).append(";");
+			set_trace(2, "get band", cmd.c_str());
 		}
 	}
 
@@ -1415,21 +1568,33 @@ void RIG_FT950::set_xcvr_auto_off()
 
 void RIG_FT950::set_compression(int on, int val)
 {
-	if (on) {
-		if (val == 0) {
-			cmd.assign("PR2;");	// mic eq on
-			sendCommand(cmd);
-			showresp(WARN, ASC, "set Comp EQ on", cmd, replystr);
-		} else {
-			cmd.assign("PR1;PL").append(to_decimal(val, 3)).append(";");
-			sendCommand(cmd);
-			showresp(WARN, ASC, "set Comp on", cmd, replystr);
-		}
-	} else{
-		cmd.assign("PR0;");
-		sendCommand(cmd);
-		showresp(WARN, ASC, "set Comp off", cmd, replystr);
-	}
+	cmd.assign("PL").append(to_decimal(val, 3)).append(";");
+	sendCommand(cmd);
+	showresp(INFO, ASC, "set Comp level", cmd, replystr);
+
+	cmd.assign( on ? "PR1;" : "PR0;");
+	sendCommand(cmd);
+	showresp(INFO, ASC, "set Comp on/off", cmd, replystr);
+	rig_trace(2, "set compression on/off", cmd.c_str());
+
+}
+
+void RIG_FT950::get_compression( int &on, int &val )
+{
+	on = progStatus.compON;
+	val = progStatus.compression;
+
+	cmd.assign("PL;");
+	wait_char(';', 6, FL950_WAIT_TIME, "GET compression value", ASC);
+	size_t p = replystr.rfind("PL");
+	if (p == string::npos) return;
+	val = fm_decimal(replystr.substr(p+3),2);
+
+	cmd.assign("PR;");
+	wait_char(';', 4, FL950_WAIT_TIME, "GET compression on/off", ASC);
+	p = replystr.rfind("PR");
+	if (p == string::npos) return;
+	on = (replystr[p+2] == '1');
 }
 
 /*
