@@ -94,17 +94,20 @@ static int agcval = 1;
 static bool fm_mode = false;
 
 static GUI rig_widgets[]= {
-	{ (Fl_Widget *)btnVol,        2, 125,  50 },
-	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
-	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 },
-	{ (Fl_Widget *)btnIFsh,     214, 105,  50 },
-	{ (Fl_Widget *)sldrIFSHIFT, 266, 105, 156 },
-	{ (Fl_Widget *)btnDataPort, 214, 125,  50 },
-	{ (Fl_Widget *)sldrMICGAIN, 266, 125, 156 },
-	{ (Fl_Widget *)sldrPOWER,   266, 145, 156 },
+	{ (Fl_Widget *)btnVol,        2, 125,  50 }, // 0
+	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 }, // 1
+	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 }, // 2
+	{ (Fl_Widget *)btnIFsh,     214, 105,  50 }, // 3
+	{ (Fl_Widget *)sldrIFSHIFT, 266, 105, 156 }, // 4
+	{ (Fl_Widget *)btnDataPort, 214, 125,  50 }, // 5
+	{ (Fl_Widget *)sldrSQUELCH, 266, 125, 156 }, // 6
+	{ (Fl_Widget *)sldrMICGAIN, 266, 145, 156 }, // 7
+	{ (Fl_Widget *)sldrPOWER,    54, 165, 368 }, // 8
 	{ (Fl_Widget *)NULL,          0,   0,   0 }
 };
 
+static string menu012 = "EX01200004";
+
 void RIG_TS480SAT::initialize()
 {
 	rig_widgets[0].W = btnVol;
@@ -113,10 +116,23 @@ void RIG_TS480SAT::initialize()
 	rig_widgets[3].W = btnIFsh;
 	rig_widgets[4].W = sldrIFSHIFT;
 	rig_widgets[5].W = btnDataPort;
-	rig_widgets[6].W = sldrMICGAIN;
-	rig_widgets[7].W = sldrPOWER;
+	rig_widgets[6].W = sldrSQUELCH;
+	rig_widgets[7].W = sldrMICGAIN;
+	rig_widgets[8].W = sldrPOWER;
 
 	check_menu_45();
+
+	menu012.clear();
+	cmd = "EX0120000;"; // read menu 012 state
+//might return something like EX01200004;
+	gett("read menu 12");
+
+	if (wait_char(';', 11, 100, "read ex 012", ASC) == 11)
+		menu012 = replystr;
+
+	cmd = "EX01200000;";
+	sendCommand(cmd);
+	sett("set menu 12");
 };
 
 RIG_TS480SAT::RIG_TS480SAT() {
@@ -235,138 +251,16 @@ void RIG_TS480SAT::check_menu_45()
 		SH_label   = TS480SAT_btn_SH_label;
 		B.iBW = A.iBW = 0x8A03;
 	}
+	gett("check menu 45");
 }
 
 void RIG_TS480SAT::shutdown()
 {
-}
-
-void RIG_TS480SAT::selectA()
-{
-	cmd = "FR0;FT0;";
+// restore state of xcvr beeps
+	if (menu012.empty()) return;
+	cmd = menu012;
 	sendCommand(cmd);
-	showresp(WARN, ASC, "Rx on A, Tx on A", cmd, "");
-}
-
-void RIG_TS480SAT::selectB()
-{
-	cmd = "FR1;FT1;";
-	sendCommand(cmd);
-	showresp(WARN, ASC, "Rx on B, Tx on B", cmd, "");
-}
-
-void RIG_TS480SAT::set_split(bool val) 
-{
-	split = val;
-	split = val;
-	if (useB) {
-		if (val) {
-			cmd = "FR1;FT0;";
-			sendCommand(cmd);
-			showresp(WARN, ASC, "Rx on B, Tx on A", cmd, "");
-		} else {
-			cmd = "FR1;FT1;";
-			sendCommand(cmd);
-			showresp(WARN, ASC, "Rx on B, Tx on B", cmd, "");
-		}
-	} else {
-		if (val) {
-			cmd = "FR0;FT1;";
-			sendCommand(cmd);
-			showresp(WARN, ASC, "Rx on A, Tx on B", cmd, "");
-		} else {
-			cmd = "FR0;FT0;";
-			sendCommand(cmd);
-			showresp(WARN, ASC, "Rx on A, Tx on A", cmd, "");
-		}
-	}
-	Fl::awake(highlight_vfo, (void *)0);
-}
-
-bool RIG_TS480SAT::can_split()
-{
-	return true;
-}
-
-int RIG_TS480SAT::get_split()
-{
-	size_t p;
-	int split = 0;
-	char rx = 0, tx = 0;
-// tx vfo
-	cmd = rsp = "FT";
-	cmd.append(";");
-	if (wait_char(';', 4, 100, "get split tx vfo", ASC) == 4) {
-		p = replystr.rfind(rsp);
-		if (p == string::npos) return split;
-		tx = replystr[p+2];
-	}
-// rx vfo
-	cmd = rsp = "FR";
-	cmd.append(";");
-	if (wait_char(';', 4, 100, "get split rx vfo", ASC) == 4) {
-		p = replystr.rfind(rsp);
-		if (p == string::npos) return split;
-		rx = replystr[p+2];
-// split test
-		split = (tx == '1' ? 2 : 0) + (rx == '1' ? 1 : 0);
-	}
-
-	return split;
-}
-
-long RIG_TS480SAT::get_vfoA ()
-{
-	cmd = "FA;";
-	if (wait_char(';', 14, 100, "get vfo A", ASC) < 14) return A.freq;
-
-	size_t p = replystr.rfind("FA");
-	if (p != string::npos && (p + 12 < replystr.length())) {
-		int f = 0;
-		for (size_t n = 2; n < 13; n++)
-			f = f*10 + replystr[p+n] - '0';
-		A.freq = f;
-	}
-	return A.freq;
-}
-
-void RIG_TS480SAT::set_vfoA (long freq)
-{
-	A.freq = freq;
-	cmd = "FA00000000000;";
-	for (int i = 12; i > 1; i--) {
-		cmd[i] += freq % 10;
-		freq /= 10;
-	}
-	sendCommand(cmd);
-	showresp(WARN, ASC, "set vfo A", cmd, "");
-}
-
-long RIG_TS480SAT::get_vfoB ()
-{
-	cmd = "FB;";
-	if (wait_char(';', 14, 100, "get vfo B", ASC) < 14) return B.freq;
-
-	size_t p = replystr.rfind("FB");
-	if (p != string::npos && (p + 12 < replystr.length())) {
-		int f = 0;
-		for (size_t n = 2; n < 13; n++)
-			f = f*10 + replystr[p+n] - '0';
-		B.freq = f;
-	}
-	return B.freq;
-}
-
-void RIG_TS480SAT::set_vfoB (long freq)
-{
-	B.freq = freq;
-	cmd = "FB00000000000;";
-	for (int i = 12; i > 1; i--) {
-		cmd[i] += freq % 10;
-		freq /= 10;
-	}
-	sendCommand(cmd);
-	showresp(WARN, ASC, "set vfo B", cmd, "");
+	sett("shutdown, restore menu 12");
 }
 
 // SM cmd 0 ... 100 (rig values 0 ... 15)
@@ -379,9 +273,21 @@ int RIG_TS480SAT::get_smeter()
 	size_t p = replystr.rfind("SM");
 	if (p != string::npos)
 		mtr = 5 * atoi(&replystr[p + 3]);
+	gett("get smeter");
 	return mtr;
 }
 
+struct pwrpair {int mtr; float pwr;};
+
+static pwrpair pwrtbl[] = { 
+	{0, 0.0}, 
+	{2, 5.0},
+	{4, 10.0}, 
+	{7, 25.0}, 
+	{11, 50.0}, 
+	{16, 100.0}, 
+	{20, 200.0} };
+
 int RIG_TS480SAT::get_power_out()
 {
 	int mtr = 0;
@@ -390,9 +296,19 @@ int RIG_TS480SAT::get_power_out()
 
 	size_t p = replystr.rfind("SM");
 	if (p != string::npos) {
-		mtr = 5 * atoi(&replystr[p + 3]);
-		if (mtr > 100) mtr = 100;
+		mtr = atoi(&replystr[p + 3]);
+
+		size_t i = 0;
+		for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+			if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
+				break;
+		if (mtr < 0) mtr = 0;
+		if (mtr > 20) mtr = 20;
+		mtr = (int)ceil(pwrtbl[i].pwr + 
+			(pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+		if (mtr > 200) mtr = 200;
 	}
+	gett("power out");
 	return mtr;
 }
 
@@ -418,6 +334,7 @@ int RIG_TS480SAT::get_swr()
 	else
 		alc = 0;
 	swralc_polled = true;
+	gett("swr");
 	return mtr;
 }
 
@@ -520,6 +437,7 @@ void RIG_TS480SAT::set_modeA(int val)
 	sendCommand(cmd);
 	showresp(WARN, ASC, "set mode", cmd, "");
 	A.iBW = set_widths(val);
+	sett("set mode A");
 }
 
 int RIG_TS480SAT::get_modeA()
@@ -537,6 +455,7 @@ int RIG_TS480SAT::get_modeA()
 	}
 	if (A.imode == 3) fm_mode = true;
 	else fm_mode = false;
+	gett("mode A");
 	return A.imode;
 }
 
@@ -551,6 +470,7 @@ void RIG_TS480SAT::set_modeB(int val)
 	sendCommand(cmd);
 	showresp(WARN, ASC, "set mode B", cmd, "");
 	B.iBW = set_widths(val);
+	sett("mode B");
 }
 
 int RIG_TS480SAT::get_modeB()
@@ -568,6 +488,7 @@ int RIG_TS480SAT::get_modeB()
 	}
 	if (B.imode == 3) fm_mode = true;
 	else fm_mode = false;
+	gett("mode B");
 	return B.imode;
 }
 
@@ -589,6 +510,7 @@ void RIG_TS480SAT::set_bwA(int val)
 		cmd.append(to_decimal(((A.iBW >> 8) & 0x7F), 2)).append(";");
 		sendCommand(cmd);
 		showresp(WARN, ASC, SH_tooltip, cmd, "");
+		sett("bw A");
 	}
 	if (val > 256) return;
 	else if (A.imode == 2 || A.imode == 6) {
@@ -596,11 +518,13 @@ void RIG_TS480SAT::set_bwA(int val)
 		cmd = TS480SAT_CWbw[A.iBW];
 		sendCommand(cmd);
 		showresp(WARN, ASC, "set CW bw", cmd, "");
+		sett("bw A");
 	}else if (A.imode == 5 || A.imode == 7) {
 		A.iBW = val;
 		cmd = TS480SAT_FSKbw[A.iBW];
 		sendCommand(cmd);
 		showresp(WARN, ASC, "set FSK bw", cmd, "");
+		sett("bw A");
 	}
 }
 
@@ -655,6 +579,7 @@ int RIG_TS480SAT::get_bwA()
 			}
 		}
 	}
+	gett("get bw A");
 	return A.iBW;
 }
 
@@ -671,6 +596,7 @@ void RIG_TS480SAT::set_bwB(int val)
 		cmd.append(to_decimal(((B.iBW >> 8) & 0x7F), 2)).append(";");
 		sendCommand(cmd);
 		showresp(WARN, ASC, SH_tooltip, cmd, "");
+		sett("bw B");
 	}
 	if (val > 256) return;
 	else if (B.imode == 2 || B.imode == 6) { // CW
@@ -678,11 +604,13 @@ void RIG_TS480SAT::set_bwB(int val)
 		cmd = TS480SAT_CWbw[B.iBW];
 		sendCommand(cmd);
 		showresp(WARN, ASC, "set CW bw", cmd, "");
+		sett("bw B");
 	}else if (B.imode == 5 || B.imode == 7) {
 		B.iBW = val;
 		cmd = TS480SAT_FSKbw[B.iBW];
 		sendCommand(cmd);
 		showresp(WARN, ASC, "set FSK bw", cmd, "");
+		sett("bw B");
 	}
 }
 
@@ -736,6 +664,7 @@ int RIG_TS480SAT::get_bwB()
 			}
 		}
 	}
+	gett("bw B");
 	return B.iBW;
 }
 
@@ -758,31 +687,6 @@ int RIG_TS480SAT::def_bandwidth(int val)
 	return adjust_bandwidth(val);
 }
 
-void RIG_TS480SAT::set_volume_control(int val)
-{
-	cmd = "AG";
-	char szval[5];
-	snprintf(szval, sizeof(szval), "%04d", val * 255 / 100);
-	cmd += szval;
-	cmd += ';';
-	LOG_WARN("%s", cmd.c_str());
-	sendCommand(cmd);
-}
-
-int RIG_TS480SAT::get_volume_control()
-{
-	int val = progStatus.volume;
-	cmd = "AG0;";
-	if (wait_char(';', 7, 100, "get vol", ASC) < 7) return val;
-
-	size_t p = replystr.rfind("AG");
-	if (p == string::npos) return val;
-	replystr[p + 6] = 0;
-	val = atoi(&replystr[p + 3]);
-	val = val * 100 / 255;
-	return val;
-}
-
 void RIG_TS480SAT::set_power_control(double val)
 {
 	cmd = "PC";
@@ -793,6 +697,7 @@ void RIG_TS480SAT::set_power_control(double val)
 	cmd += ';';
 	LOG_WARN("%s", cmd.c_str());
 	sendCommand(cmd);
+	sett("power control");
 }
 
 int RIG_TS480SAT::get_power_control()
@@ -805,7 +710,7 @@ int RIG_TS480SAT::get_power_control()
 	if (p == string::npos) return val;
 
 	val = atoi(&replystr[p + 2]);
-
+	gett("power control");
 	return val;
 }
 
@@ -815,6 +720,7 @@ void RIG_TS480SAT::set_attenuator(int val)
 	else		cmd = "RA00;";
 	LOG_WARN("%s", cmd.c_str());
 	sendCommand(cmd);
+	sett("attenuator");
 }
 
 int RIG_TS480SAT::get_attenuator()
@@ -823,6 +729,7 @@ int RIG_TS480SAT::get_attenuator()
 	if (wait_char(';', 7, 100, "get attenuator", ASC) < 7) return progStatus.attenuator;
 
 	size_t p = replystr.rfind("RA");
+	gett("attenuator");
 	if (p == string::npos) return progStatus.attenuator;
 	if (replystr[p+3] == '1') return 1;
 	return 0;
@@ -834,6 +741,7 @@ void RIG_TS480SAT::set_preamp(int val)
 	else		cmd = "PA0;";
 	LOG_WARN("%s", cmd.c_str());
 	sendCommand(cmd);
+	sett("preamp");
 }
 
 int RIG_TS480SAT::get_preamp()
@@ -842,18 +750,12 @@ int RIG_TS480SAT::get_preamp()
 	if (wait_char(';', 5, 100, "get preamp", ASC) < 5) return progStatus.preamp;
 
 	size_t p = replystr.rfind("PA");
+	gett("preamp");
 	if (p == string::npos) return progStatus.preamp;
 	if (replystr[p+2] == '1') return 1;
 	return 0;
 }
 
-void RIG_TS480SAT::tune_rig()
-{
-	cmd = "AC111;";
-	LOG_WARN("%s", cmd.c_str());
-	sendCommand(cmd);
-}
-
 void RIG_TS480SAT::set_if_shift(int val)
 {
 	cmd = "IS+";
@@ -861,6 +763,7 @@ void RIG_TS480SAT::set_if_shift(int val)
 	cmd.append(to_decimal(abs(val),4)).append(";");
 	sendCommand(cmd);
 	showresp(WARN, ASC, "set IF shift", cmd, "");
+	sett("if shift");
 }
 
 bool RIG_TS480SAT::get_if_shift(int &val)
@@ -868,6 +771,7 @@ bool RIG_TS480SAT::get_if_shift(int &val)
 	cmd = "IS;";
 	if (wait_char(';', 8, 100, "get IF shift", ASC) == 8) {
 		size_t p = replystr.rfind("IS");
+		gett("if shift");
 		if (p != string::npos) {
 			val = fm_decimal(replystr.substr(p+3), 4);
 			if (replystr[p+2] == '-') val *= -1;
@@ -886,56 +790,6 @@ void RIG_TS480SAT::get_if_min_max_step(int &min, int &max, int &step)
 	if_shift_mid = 0;
 }
 
-void RIG_TS480SAT::set_mic_gain(int val)
-{
-	cmd = "MG";
-	cmd.append(to_decimal(val,3)).append(";");
-	sendCommand(cmd);
-	showresp(WARN, ASC, "set mic gain", cmd, "");
-}
-
-int  RIG_TS480SAT::get_mic_gain()
-{
-	int val = progStatus.mic_gain;
-	cmd = "MG;";
-	if (wait_char(';', 6, 100, "get mic gain", ASC) < 6) return val;
-
-	size_t p = replystr.rfind("MG");
-	if (p != string::npos)
-		val = fm_decimal(replystr.substr(p+2), 3);
-	return val;
-}
-
-void RIG_TS480SAT::get_mic_min_max_step(int &min, int &max, int &step)
-{
-	min = 0; max = 100; step = 1;
-}
-
-void RIG_TS480SAT::set_rf_gain(int val)	
-{
-	cmd = "RG";
-	cmd.append(to_decimal(val,3)).append(";");
-	sendCommand(cmd);
-	showresp(WARN, ASC, "set rf gain", cmd, "");
-}
-
-int  RIG_TS480SAT::get_rf_gain()
-{
-	int val = progStatus.rfgain;
-	cmd = "RG;";
-	if (wait_char(';', 6, 100, "get rf gain", ASC) < 6) return val;
-
-	size_t p = replystr.rfind("RG");
-	if (p != string::npos)
-		val = fm_decimal(replystr.substr(p+2), 3);
-	return val;
-}
-
-void RIG_TS480SAT::get_rf_min_max_step(int &min, int &max, int &step)
-{
-	min = 0; max = 100; step = 1;
-}
-
 // Noise Reduction (TS2000.cxx) NR1 only works; no NR2 and don' no why
 void RIG_TS480SAT::set_noise_reduction(int val)
 {
@@ -955,6 +809,7 @@ void RIG_TS480SAT::set_noise_reduction(int val)
 	cmd += ';';
 	sendCommand (cmd);
 	showresp(WARN, ASC, "SET noise reduction", cmd, "");
+	sett("noise reduction");
 }
 
 int  RIG_TS480SAT::get_noise_reduction()
@@ -974,7 +829,7 @@ int  RIG_TS480SAT::get_noise_reduction()
 	} else {
 		nr_label("NR", false);
 	}
-
+	gett("noise reduction");
 	return _noise_reduction_level;
 }
 
@@ -987,6 +842,7 @@ void RIG_TS480SAT::set_noise_reduction_val(int val)
 	cmd.assign("RL").append(to_decimal(val, 2)).append(";");
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET_noise_reduction_val", cmd, "");
+	sett("nr value");
 }
 
 int  RIG_TS480SAT::get_noise_reduction_val()
@@ -1007,7 +863,7 @@ int  RIG_TS480SAT::get_noise_reduction_val()
 
 	if (_noise_reduction_level == 1) _nrval1 = val;
 	else _nrval2 = val;
-
+	gett("nr value");
 	return val;
 }
 
@@ -1016,9 +872,11 @@ int  RIG_TS480SAT::get_agc()
 	cmd = "GT;";
 	wait_char(';', 6, 100, "GET agc val", ASC);
 	size_t p = replystr.rfind("GT");
+	gett("agc");
 	if (p == string::npos) return agcval;
 	if (replystr[4] == ' ') return 0;
 	agcval = replystr[4] - '0' + 1; // '0' == off, '1' = fast, '2' = slow
+
 	return agcval;
 }
 
@@ -1032,6 +890,7 @@ int RIG_TS480SAT::incr_agc()
 	cmd += ";";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "SET agc", cmd, replystr);
+	sett("increment agc");
 	return agcval;
 }
 
@@ -1055,7 +914,7 @@ void RIG_TS480SAT::set_auto_notch(int v)
 	cmd = v ? "BC1;" : "BC0;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "set auto notch", cmd, "");
-
+	sett("auto notch");
 }
 
 int  RIG_TS480SAT::get_auto_notch()
@@ -1064,6 +923,7 @@ int  RIG_TS480SAT::get_auto_notch()
 	if (wait_char(';', 4, 100, "get auto notch", ASC) == 4) {
 		int anotch = 0;
 		size_t p = replystr.rfind("BC");
+		gett("auto notch");
 		if (p != string::npos) {
 			anotch = (replystr[p+2] == '1');
 			return anotch;
@@ -1081,6 +941,7 @@ void RIG_TS480SAT::set_noise(bool b)
 		cmd = "NB0;";
 	sendCommand(cmd);
 	showresp(WARN, ASC, "set NB", cmd, "");
+	sett("noise");
 }
 
 int RIG_TS480SAT::get_noise()
@@ -1088,12 +949,189 @@ int RIG_TS480SAT::get_noise()
 	cmd = "NB;";
 	if (wait_char(';', 4, 100, "get Noise Blanker", ASC) == 4) {
 		size_t p = replystr.rfind("NB");
+		gett("noise");
 		if (p == string::npos) return 0;
 		if (replystr[p+2] == '0') return 0;
 	}
 	return 1;
 }
 
+// Tranceiver PTT on/off
+void RIG_TS480SAT::set_PTT_control(int val)
+{
+	if (val) {
+		if (progStatus.data_port) cmd = "TX1;"; // DTS transmission using ANI input
+		else cmd = "TX0;"; // mic input
+	} else cmd = "RX;";
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set PTT", cmd, "");
+	sett("ptt");
+}
+
+int RIG_TS480SAT::get_PTT()
+{
+	cmd = "IF;";
+	int ret = wait_char(';', 38, 100, "get VFO", ASC);
+	gett("ptt");
+	if (ret < 38) return ptt_;
+	ptt_ = (replybuff[28] == '1');
+	return ptt_;
+}
+
+void RIG_TS480SAT::set_rf_gain(int val)	
+{
+	cmd = "RG";
+	cmd.append(to_decimal(val,3)).append(";");
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set rf gain", cmd, "");
+	sett("rf gain");
+}
+
+int  RIG_TS480SAT::get_rf_gain()
+{
+	int val = progStatus.rfgain;
+	cmd = "RG;";
+	if (wait_char(';', 6, 100, "get rf gain", ASC) < 6) return val;
+
+	size_t p = replystr.rfind("RG");
+	if (p != string::npos)
+		val = fm_decimal(replystr.substr(p+2), 3);
+	gett("rf gain");
+	return val;
+}
+
+void RIG_TS480SAT::get_rf_min_max_step(int &min, int &max, int &step)
+{
+	min = 0; max = 100; step = 1;
+}
+
+/*
+void RIG_TS480SAT::selectA()
+{
+	cmd = "FR0;FT0;";
+	sendCommand(cmd);
+	showresp(WARN, ASC, "Rx on A, Tx on A", cmd, "");
+}
+
+void RIG_TS480SAT::selectB()
+{
+	cmd = "FR1;FT1;";
+	sendCommand(cmd);
+	showresp(WARN, ASC, "Rx on B, Tx on B", cmd, "");
+}
+
+void RIG_TS480SAT::set_split(bool val) 
+{
+	split = val;
+	if (useB) {
+		if (val) {
+			cmd = "FR1;FT0;";
+			sendCommand(cmd);
+			showresp(WARN, ASC, "Rx on B, Tx on A", cmd, "");
+		} else {
+			cmd = "FR1;FT1;";
+			sendCommand(cmd);
+			showresp(WARN, ASC, "Rx on B, Tx on B", cmd, "");
+		}
+	} else {
+		if (val) {
+			cmd = "FR0;FT1;";
+			sendCommand(cmd);
+			showresp(WARN, ASC, "Rx on A, Tx on B", cmd, "");
+		} else {
+			cmd = "FR0;FT0;";
+			sendCommand(cmd);
+			showresp(WARN, ASC, "Rx on A, Tx on A", cmd, "");
+		}
+	}
+}
+
+bool RIG_TS480SAT::can_split()
+{
+	return true;
+}
+
+int RIG_TS480SAT::get_split()
+{
+	size_t p;
+	int split = 0;
+	char rx = 0, tx = 0;
+// tx vfo
+	cmd = rsp = "FT";
+	cmd.append(";");
+	if (wait_char(';', 4, 100, "get split tx vfo", ASC) == 4) {
+		p = replystr.rfind(rsp);
+		if (p == string::npos) return split;
+		tx = replystr[p+2];
+	}
+// rx vfo
+	cmd = rsp = "FR";
+	cmd.append(";");
+	if (wait_char(';', 4, 100, "get split rx vfo", ASC) == 4) {
+		p = replystr.rfind(rsp);
+		if (p == string::npos) return split;
+		rx = replystr[p+2];
+// split test
+		split = (tx == '1' ? 2 : 0) + (rx == '1' ? 1 : 0);
+	}
+
+	return split;
+}
+
+long RIG_TS480SAT::get_vfoA ()
+{
+	cmd = "FA;";
+	if (wait_char(';', 14, 100, "get vfo A", ASC) < 14) return A.freq;
+
+	size_t p = replystr.rfind("FA");
+	if (p != string::npos && (p + 12 < replystr.length())) {
+		int f = 0;
+		for (size_t n = 2; n < 13; n++)
+			f = f*10 + replystr[p+n] - '0';
+		A.freq = f;
+	}
+	return A.freq;
+}
+
+void RIG_TS480SAT::set_vfoA (long freq)
+{
+	A.freq = freq;
+	cmd = "FA00000000000;";
+	for (int i = 12; i > 1; i--) {
+		cmd[i] += freq % 10;
+		freq /= 10;
+	}
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set vfo A", cmd, "");
+}
+
+long RIG_TS480SAT::get_vfoB ()
+{
+	cmd = "FB;";
+	if (wait_char(';', 14, 100, "get vfo B", ASC) < 14) return B.freq;
+
+	size_t p = replystr.rfind("FB");
+	if (p != string::npos && (p + 12 < replystr.length())) {
+		int f = 0;
+		for (size_t n = 2; n < 13; n++)
+			f = f*10 + replystr[p+n] - '0';
+		B.freq = f;
+	}
+	return B.freq;
+}
+
+void RIG_TS480SAT::set_vfoB (long freq)
+{
+	B.freq = freq;
+	cmd = "FB00000000000;";
+	for (int i = 12; i > 1; i--) {
+		cmd[i] += freq % 10;
+		freq /= 10;
+	}
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set vfo B", cmd, "");
+}
+
 // Squelch (TS990.cxx)
 void RIG_TS480SAT::set_squelch(int val)
 {
@@ -1121,48 +1159,62 @@ void RIG_TS480SAT::get_squelch_min_max_step(int &min, int &max, int &step)
 	min = 0; max = 255; step = 1;
 }
 
-// Tranceiver PTT on/off
-void RIG_TS480SAT::set_PTT_control(int val)
+void RIG_TS480SAT::set_mic_gain(int val)
 {
-	if (val) {
-		if (progStatus.data_port) cmd = "TX1;"; // DTS transmission using ANI input
-		else cmd = "TX0;"; // mic input
-	} else cmd = "RX;";
+	cmd = "MG";
+	cmd.append(to_decimal(val,3)).append(";");
 	sendCommand(cmd);
-	showresp(WARN, ASC, "set PTT", cmd, "");
+	showresp(WARN, ASC, "set mic gain", cmd, "");
 }
 
-/*
-========================================================================
-	frequency & mode data are contained in the IF; response
-		IFaaaaaaaaaaaXXXXXbbbbbcdXeefghjklmmX;
-		12345678901234567890123456789012345678
-		01234567890123456789012345678901234567 byte #
-		          1         2         3
-		                            ^ position 28
-		where:
-			aaaaaaaaaaa => decimal value of vfo frequency
-			bbbbb => rit/xit frequency
-			c => rit off/on
-			d => xit off/on
-			e => memory channel
-			f => tx/rx
-			g => mode
-			h => function
-			j => scan off/on
-			k => split off /on
-			l => tone off /on
-			m => tone number
-			X => unused characters
-		 
-========================================================================
-*/ 
-
-int RIG_TS480SAT::get_PTT()
+int  RIG_TS480SAT::get_mic_gain()
 {
-	cmd = "IF;";
-	int ret = wait_char(';', 38, 100, "get VFO", ASC);
-	if (ret < 38) return ptt_;
-	ptt_ = (replybuff[28] == '1');
-	return ptt_;
+	int val = progStatus.mic_gain;
+	cmd = "MG;";
+	if (wait_char(';', 6, 100, "get mic gain", ASC) < 6) return val;
+
+	size_t p = replystr.rfind("MG");
+	if (p != string::npos)
+		val = fm_decimal(replystr.substr(p+2), 3);
+	return val;
 }
+
+void RIG_TS480SAT::get_mic_min_max_step(int &min, int &max, int &step)
+{
+	min = 0; max = 100; step = 1;
+}
+
+
+void RIG_TS480SAT::set_volume_control(int val)
+{
+	cmd = "AG";
+	char szval[5];
+	snprintf(szval, sizeof(szval), "%04d", val * 255 / 100);
+	cmd += szval;
+	cmd += ';';
+	LOG_WARN("%s", cmd.c_str());
+	sendCommand(cmd);
+}
+
+int RIG_TS480SAT::get_volume_control()
+{
+	int val = progStatus.volume;
+	cmd = "AG0;";
+	if (wait_char(';', 7, 100, "get vol", ASC) < 7) return val;
+
+	size_t p = replystr.rfind("AG");
+	if (p == string::npos) return val;
+	replystr[p + 6] = 0;
+	val = atoi(&replystr[p + 3]);
+	val = val * 100 / 255;
+	return val;
+}
+
+void RIG_TS480SAT::tune_rig()
+{
+	cmd = "AC111;";
+	LOG_WARN("%s", cmd.c_str());
+	sendCommand(cmd);
+}
+
+*/
