@@ -719,6 +719,14 @@ const char * RIG_TS990::get_bwname_(int n, int md)
 // Get/Set VFO for A and B
 //==============================================================================
 
+bool RIG_TS990::check ()
+{
+	cmd = "FA;";
+	int ret = wait_char(';', 14, 100, "check", ASC);
+	if (ret < 14) return false;
+	return true;
+}
+
 long RIG_TS990::get_vfoA ()
 {
 	ts990debug("get_vfoA()");
@@ -2781,10 +2789,11 @@ int  RIG_TS990::get_rf_gain()
 		if (wait_char(';', 7, TS990_WAIT, "get rf gain", ASC) < 7) return val;
 
 		size_t p = replystr.rfind("RG");
-		if (p != string::npos)
+		if (p != string::npos) {
 			val = fm_decimal(replystr.substr(p+3), 3);
 			val *= 100;
 			val /= 255;
+		}
 	} else {
 		cmd = "RG0;";
 		if (wait_char(';', 7, TS990_WAIT, "get rf gain", ASC) < 7) return val;
