@@ -38,6 +38,7 @@ static GUI basewidgets[] = { {NULL, 0, 0} };
 
 rigbase::rigbase()
 {
+	IDstr = "";
 	name_ = szNORIG;
 	modes_ = szNOMODES;
 	bandwidths_ = szNOBWS;
@@ -48,7 +49,6 @@ rigbase::rigbase()
 	SH_tooltip = szdsptooltip;
 	SH_label = szbtnlabel;
 	bw_vals_ = &ibw_val;
-	bw_size_ = 0;
 
 	widgets = basewidgets;
 
@@ -81,6 +81,8 @@ rigbase::rigbase()
 	has_attenuator_control =
 	has_preamp_control =
 	has_ifshift_control =
+	has_pbt_controls =
+	has_FILTER =
 	has_ptt_control =
 	has_tune_control =
 	has_swr_control =
@@ -117,14 +119,16 @@ rigbase::rigbase()
 	has_smeter =
 	has_power_out =
 	has_line_out =
-	has_split =
+//	has_split =
 	has_split_AB =
-	has_a2b =
 	has_band_selection =
 	has_get_info = 
-	has_getvfoAorB = false;
+	has_getvfoAorB = 
+	ICOMrig = false;
+	ICOMmainsub = false;
 
-	has_vfoAB = true;
+	has_a2b = false;
+	has_vfoAB = false;
 
 	data_type = BINARY;
 
@@ -152,6 +156,8 @@ rigbase::rigbase()
 	bpf_center = 0;
 	pbt = 0;
 
+	rTONE = tTONE = 8;
+
 	max_power = 100;
 
 	active_mode = 0; // wbx
@@ -345,6 +351,8 @@ int rigbase::num100(string bcd)
 
 int rigbase::waitN(size_t n, int timeout, const char *sz, int pr)
 {
+	guard_lock reply_lock(&mutex_replystr);
+
 	char sztemp[50];
 	string returned = "";
 	string tosend = cmd;
@@ -355,6 +363,7 @@ int rigbase::waitN(size_t n, int timeout, const char *sz, int pr)
 			progStatus.use_tcpip ? progStatus.tcpip_ping_delay : 0;
 
 	replystr.clear();
+	RigSerial->FlushBuffer();
 
 	if(!progStatus.use_tcpip && !RigSerial->IsOpen()) {
 		snprintf(sztemp, sizeof(sztemp), "TEST %s", sz);
@@ -368,7 +377,7 @@ int rigbase::waitN(size_t n, int timeout, const char *sz, int pr)
 	returned = "";
 	for ( cnt = 0; cnt < timeout / 10; cnt++) {
 		readResponse();
-		returned.append(replystr);
+		returned.append(respstr);
 		if (returned.length() >= n) {
 			replystr = returned;
 			waited = cnt * 10 + delay;
@@ -391,6 +400,8 @@ int report_level = INFO;
 
 int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 {
+	guard_lock reply_lock(&mutex_replystr);
+
 	char sztemp[50];
 	string returned = "";
 	string tosend = cmd;
@@ -402,6 +413,7 @@ int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 			progStatus.use_tcpip ? progStatus.tcpip_ping_delay : 0;
 
 	replystr.clear();
+	RigSerial->FlushBuffer();
 
 	if(!progStatus.use_tcpip && !RigSerial->IsOpen()) {
 		snprintf(sztemp, sizeof(sztemp), "TEST %s", sz);
@@ -415,7 +427,7 @@ int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 	returned = "";
 	for ( cnt = 0; cnt < timeout / 10; cnt++) {
 		readResponse();
-		returned.append(replystr);
+		returned.append(respstr);
 		if (returned.find(ch) != string::npos) {
 			replystr = returned;
 			waited = cnt * 10 + delay;
@@ -434,4 +446,52 @@ int rigbase::wait_char(int ch, size_t n, int timeout, const char *sz, int pr)
 	return 0;
 }
 
+// Yaesu transceiver - wait for response to identifier request
+// return boolean state of response
+// ID  - for most
+// AI  - for FTdx9000
+// wait - wait nnn milliseconds before declaring transceiver DOA
+//        default 200 msec
+// retry - number of retries, default 
+bool rigbase::id_OK(string ID, int wait)
+{
+	guard_lock reply_lock(&mutex_replystr);
 
+	string returned;
+	for (int n = 0; n < progStatus.comm_retries; n++) {
+		sendCommand(string(ID).append(";", 0));
+		returned = "";
+		for (int cnt = 0; cnt < wait / 10; cnt++) {
+			readResponse();
+			returned.append(respstr);
+			if (returned.find(ID)) {
+				replystr = returned;
+				return true;
+			}
+			MilliSleep(10);
+			Fl::awake();
+		}
+	}
+	replystr.clear();
+	return false;
+}
+
+void rigbase::sendOK(string cmd)
+{
+	if (IDstr.empty()) {
+		sendCommand(cmd,0);
+		return;
+	}
+	if (id_OK(IDstr, 100))
+		sendCommand(cmd, 0);
+}
+
+void rigbase::set_split(bool val) 
+{
+	split = val;
+}
+
+int  rigbase::get_split() 
+{
+	return split;
+}
