@@ -32,6 +32,7 @@
 #include "rigpanel.h"
 #include "rigbase.h"
 #include "font_browser.h"
+#include "ui.h"
 
 #include <string>
 
@@ -330,7 +331,7 @@ void cbCIVdefault()
 	char hexstr[8];
 	int picked = selectRig->index();
 	rigbase *srig = rigs[picked];
-	snprintf(hexstr, sizeof(hexstr), "0x%2X", srig->defaultCIV);
+	snprintf(hexstr, sizeof(hexstr), "0x%02X", srig->defaultCIV);
 	txtCIV->value(hexstr);
 	progStatus.CIV = srig->defaultCIV;
 	srig->adjustCIV(progStatus.CIV);
@@ -358,9 +359,9 @@ void configXcvr()
 	selectAuxPort->value(progStatus.aux_serial_port.c_str());
 	selectSepPTTPort->value(progStatus.sep_serial_port.c_str());
 
-	if (xcvr_name.find("IC") == 0) {
+	if (selrig->CIV) {
 		char hexstr[8];
-		snprintf(hexstr, sizeof(hexstr), "0x%2X", selrig->CIV);
+		snprintf(hexstr, sizeof(hexstr), "0x%02X", selrig->CIV);
 		txtCIV->value(hexstr);
 		txtCIV->activate();
 		btnCIVdefault->activate();
@@ -389,6 +390,12 @@ void open_poll_tab()
 	tabsConfig->value(tabPolling);
 }
 
+void open_trace_tab()
+{
+	dlgXcvrConfig->show();
+	tabsConfig->value(tabTRACE);
+}
+
 void open_restore_tab()
 {
 	dlgXcvrConfig->show();
@@ -864,6 +871,7 @@ void setColors()
 	if (btnAutoNotch)		btnAutoNotch->selection_color(btn_lt_color);
 	if (btnTune)			btnTune->selection_color(btn_lt_color);
 	if (btnPTT)				btnPTT->selection_color(btn_lt_color);
+	if (btnLOCK)			btnLOCK->selection_color(btn_lt_color);
 	if (btnAuxRTS)			btnAuxRTS->selection_color(btn_lt_color);
 	if (btnAuxDTR)			btnAuxDTR->selection_color(btn_lt_color);
 	if (btnSpot)			btnSpot->selection_color(btn_lt_color);
@@ -883,6 +891,10 @@ void setColors()
 	if (sldrNR)				sldrNR->selection_color(btn_slider);
 	if (sldrIFSHIFT)		sldrIFSHIFT->color(bg_slider);
 	if (sldrIFSHIFT)		sldrIFSHIFT->selection_color(btn_slider);
+	if (sldrINNER)			sldrINNER->color(bg_slider);
+	if (sldrINNER)			sldrINNER->selection_color(btn_slider);
+	if (sldrOUTER)			sldrOUTER->color(bg_slider);
+	if (sldrOUTER)			sldrOUTER->selection_color(btn_slider);
 	if (sldrNOTCH)			sldrNOTCH->color(bg_slider);
 	if (sldrNOTCH)			sldrNOTCH->selection_color(btn_slider);
 	if (sldrMICGAIN)		sldrMICGAIN->color(bg_slider);
@@ -1039,25 +1051,26 @@ void openMemoryDialog()
 
 void show_controls()
 {
-	if (!(selrig->has_extras || selrig->name_ == rig_TT550.name_) && 
-		progStatus.aux_serial_port == "NONE")
+	if (selrig->name_ == rig_TT550.name_)
 		return;
+	int wh = mainwindow->h();
+	int ww = mainwindow->w();
 	switch (progStatus.UIsize) {
 		case wide_ui :
-			if (mainwindow->h() > 150) {
+			if (mainwindow->h() > WIDE_MAINH) {
 				btn_show_controls->label("@-22->");
 				btn_show_controls->redraw_label();
 				grpTABS->hide();
-				mainwindow->resizable(grpTABS);
-				mainwindow->size(mainwindow->w(), 150);
-				mainwindow->size_range(735, 150, 0, 150);
+				mainwindow->size(mainwindow->w(), WIDE_MAINH);
+				mainwindow->size_range(735, WIDE_MAINH, 0, WIDE_MAINH);
 			} else {
+				wh += grpTABS->h();
 				btn_show_controls->label("@-28->");
 				btn_show_controls->redraw_label();
-				mainwindow->resizable(grpTABS);
-				mainwindow->size(mainwindow->w(), 220);
-				mainwindow->size_range(735, 220, 0, 220);
 				grpTABS->show();
+				grpTABS->resize(0, wh - grpTABS->h(), ww, grpTABS->h());
+				mainwindow->size(ww, wh);
+				mainwindow->size_range(735, wh, 0, wh);
 			}
 			mainwindow->redraw();
 			break;
@@ -1072,49 +1085,21 @@ void show_controls()
 			tabs550->redraw();
 			tabsGeneric->redraw();
 			mainwindow->redraw();
-			return;
+			break;
 		case small_ui :
-			{
-				int wh = mainwindow->h();
-				int ww = mainwindow->w();
 			if (selrig->name_ == rig_TT550.name_) {
 				tabsGeneric->hide();
-				if (tabs550->visible()) {
-					tabs550->hide();
-					btn_show_controls->label("@-22->");
-					btn_show_controls->redraw_label();
-					wh -= 70;
-					mainwindow->resizable(grpTABS);
-					mainwindow->size( ww, wh);
-				} else {
-					tabs550->show();
-					btn_show_controls->label("@-28->");
-					btn_show_controls->redraw_label();
-					wh += 70;
-					mainwindow->resizable(grpTABS);
-					mainwindow->size( ww, wh);
-				}
+				tabs550->show();
 			} else {
 				tabs550->hide();
-				if (tabsGeneric->visible()) {
-					tabsGeneric->hide();
-					btn_show_controls->label("@-22->");
-					btn_show_controls->redraw_label();
-					wh -= 70;
-					mainwindow->size( ww, wh);
-					mainwindow->size_range(ww, wh, ww, wh);
-				} else {
-					tabsGeneric->show();
-					btn_show_controls->label("@-28->");
-					btn_show_controls->redraw_label();
-					wh += 70;
-					mainwindow->size( ww, wh);
-					mainwindow->size_range(ww, wh, ww, wh);
-				}
+				tabsGeneric->show();
+			}
+			if (tabs_dialog->visible())
+				tabs_dialog->hide();
+			else {
+				tabs_dialog->position(mainwindow->x(), mainwindow->y() + mainwindow->h() + 26);
+				tabs_dialog->show();
 			}
-		}
-			grpTABS->show();
-			mainwindow->redraw();
 			break;
 		default :
 			break;
@@ -1407,29 +1392,27 @@ void cb_send_command(string command, Fl_Output *resp)
 		}
 	} else
 		cmd = command;
-// lock out polling loops until done
-	guard_lock gl_serial(&mutex_serial, 201);
 
 	if (resp) {
 		resp->value("");
 		resp->redraw();
 	}
 
-	sendCommand(cmd, 0);
+// lock out polling loops until done
+	guard_lock lock1(&mutex_srvc_reqs);
+	guard_lock lock2(&mutex_serial);
 
-	int timeout = 1000;
-	while (timeout > 0) {
-		if (timeout > 10) MilliSleep(10);
-		else MilliSleep(timeout);
-		timeout -= 10;
-		Fl::awake();
-	}
+	sendCommand(cmd, 0);//cmd.length());
+	set_trace(2, "command: ", command.c_str());
+	waitResponse(100);
+
+	std::string retstr = usehex ? 
+		str2hex(respstr.c_str(), respstr.length()) :
+		respstr;
+	set_trace(2, "response: ", retstr.c_str());
 
-	readResponse();
 	if (resp) {
-		resp->value(
-			usehex ? str2hex(replystr.c_str(), replystr.length()) :
-			replystr.c_str());
+		resp->value(retstr.c_str());
 		resp->redraw();
 	}
 }
